@@ -70,7 +70,7 @@ fn user_agent() -> AwsUserAgent {
 ///
 /// ## Endpoint configuration list
 /// 1. Explicit configuration of `Endpoint` via the [builder](Builder):
-/// ```rust
+/// ```no_run
 /// use aws_config::imds::client::Client;
 /// use http::Uri;
 /// # async fn docs() {
@@ -92,7 +92,7 @@ fn user_agent() -> AwsUserAgent {
 /// ```
 ///
 /// 4. An explicitly set endpoint mode:
-/// ```rust
+/// ```no_run
 /// use aws_config::imds::client::{Client, EndpointMode};
 /// # async fn docs() {
 /// let client = Client::builder().endpoint_mode(EndpointMode::IpV6).build().await;
@@ -170,7 +170,7 @@ impl Client {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```no_run
     /// use aws_config::imds::client::Client;
     /// # async fn docs() {
     /// let client = Client::builder().build().await.expect("valid client");
@@ -456,7 +456,7 @@ impl Builder {
     /// Configure generic options of the [`Client`]
     ///
     /// # Examples
-    /// ```rust
+    /// ```no_run
     /// use aws_config::imds::Client;
     /// # async fn test() {
     /// use aws_config::provider_config::ProviderConfig;
@@ -553,14 +553,17 @@ impl Builder {
             self.token_ttl.unwrap_or(DEFAULT_TOKEN_TTL),
             retry_config.clone(),
             timeout_config.clone(),
+            config.sleep(),
         );
         let middleware = ImdsMiddleware { token_loader };
         let inner_client = aws_smithy_client::Builder::new()
             .connector(connector.clone())
             .middleware(middleware)
+            .sleep_impl(config.sleep())
             .build()
             .with_retry_config(retry_config)
             .with_timeout_config(timeout_config);
+
         let client = Client {
             endpoint,
             inner: inner_client,
@@ -720,7 +723,8 @@ pub(crate) mod test {
     use std::error::Error;
     use std::time::{Duration, SystemTime, UNIX_EPOCH};
 
-    use aws_hyper::DynConnector;
+    use aws_smithy_async::rt::sleep::TokioSleep;
+    use aws_smithy_client::erase::DynConnector;
     use aws_smithy_client::test_connection::{capture_request, TestConnection};
     use aws_smithy_http::body::SdkBody;
     use aws_types::os_shim_internal::{Env, Fs, ManualTimeSource, TimeSource};
@@ -770,9 +774,11 @@ pub(crate) mod test {
         SdkBody: From<T>,
         T: Send + 'static,
     {
+        tokio::time::pause();
         super::Client::builder()
             .configure(
                 &ProviderConfig::no_configuration()
+                    .with_sleep(TokioSleep::new())
                     .with_http_connector(DynConnector::new(conn.clone())),
             )
             .build()
@@ -827,11 +833,13 @@ pub(crate) mod test {
             ),
         ]);
         let mut time_source = ManualTimeSource::new(UNIX_EPOCH);
+        tokio::time::pause();
         let client = super::Client::builder()
             .configure(
                 &ProviderConfig::no_configuration()
                     .with_http_connector(DynConnector::new(connection.clone()))
-                    .with_time_source(TimeSource::manual(&time_source)),
+                    .with_time_source(TimeSource::manual(&time_source))
+                    .with_sleep(TokioSleep::new()),
             )
             .endpoint_mode(EndpointMode::IpV6)
             .token_ttl(Duration::from_secs(600))
@@ -876,6 +884,7 @@ pub(crate) mod test {
                 imds_response(r#"test-imds-output3"#),
             ),
         ]);
+        tokio::time::pause();
         let mut time_source = ManualTimeSource::new(UNIX_EPOCH);
         let client = super::Client::builder()
             .configure(
@@ -1001,7 +1010,6 @@ pub(crate) mod test {
     }
 
     /// Verify that the end-to-end real client has a 1-second connect timeout
-    #[ignore]
     #[tokio::test]
     async fn one_second_connect_timeout() {
         let client = Client::builder()
@@ -1018,7 +1026,7 @@ pub(crate) mod test {
         assert!(now.elapsed().unwrap() > Duration::from_secs(1));
         assert!(now.elapsed().unwrap() < Duration::from_secs(2));
         match resp {
-            ImdsError::FailedToLoadToken(err) if format!("{}", err).contains("timed out") => {} // ok,
+            ImdsError::FailedToLoadToken(err) if format!("{}", err).contains("timeout") => {} // ok,
             other => panic!(
                 "wrong error, expected construction failure with TimedOutError inside: {}",
                 other
